#! page
title: A propos du projet
author: Geoffrey Le Tocquet
description: Description détaillée du projet
section: main

# À propos du projet

## Un projet de recherche participative du manteau neigeux dans les Vosges

À l'initiative de l’Observatoire Hydro-Géochimique de l'Environnement de l’Université de Strasbourg et du CNRS, et coordonné par le Jardin des sciences de l'Université de Strasbourg, ce projet ouvert et participatif vise à étudier la dynamique du manteau neigeux dans un territoire allant du massif du Brézouard au Lac Blanc. 

<figure>
	<img src="/assets/medias-site/installation_ohge_neige_1_credit_pierret.webp">
	<figcaption>Installations météorologiques de l'OHGE - crédit : Marie-Claire Pierret</figcaption>
</figure>

Ce projet vise à étudier la dynamique du manteau neigeux dans nos massifs ; son épaisseur, sa structure, ses caractéristiques, son évolution dans le temps. 
L’objectif est aussi de mieux comprendre l’impact des modifications des précipitations de neige sur l’ensemble de l’écosystème local (recharge des nappes, santé des forêts, humidité des sols ...). 
Pour cela nous avons besoin de données fiables réparties sur l’ensemble du massif pour tenir compte des variations géographiques. Nous 
collectons ces données grâce à un collectif de citoyen qui effectuent des relevés réguliers pendant l'hiver sur des zones définies.

## Dans le contexte du projet "Des traces au Brézouard

Le Jardin des sciences coordonne depuis 2021 le projet « Des Traces au Brézouard », une expérimentation de dialogue entre scientifiques, politiques, artistes et habitants. Mêlant actions culturelles, expériences citoyennes et sciences participatives, il vise à développer des gestions plus durables et collectives du territoire et améliorer la qualité de vie de ses habitants.

### « Des Traces au Brézouard » vise ainsi trois grands objectifs :

+ Renforcer la compréhension d’un territoire de moyenne montagne par différentes approches
+ Accompagner les habitants dans une démarche de réappropriation de leur territoire
+ Dépasser le stade de cohabitation entre chercheurs et citoyens pour co-construire un projet scientifique, citoyen et artistique

Ce « dialogue » intervient autour d’actions construites par des acteurs de divers horizons (associations, scientifiques, élus, artistes, etc.) impliqués localement, à destination d’une grande diversité de publics, jeunes comme plus âgés, engagés pour leur territoire ou amateurs d’actions culturelles…

<figure>
	<img src="/assets/medias-site/balade_dessinee_credit_Baptiste_Cogitore.webp" width="600">
	<figcaption>Balade dessinée de Rodéo d'Âme - crédit : Baptiste Cogitore</figcaption>
</figure>


**Quatre projets sont actuellement en cours de développement :**

1. Une résidence artistique
2. Des ateliers d’écriture de cahiers de doléance
3. Des actions de médiation scientifique à destination des jeunes
4. Contribuez à la recherche sur le manteau neigeux !

## Le protocole de recherche

### Les points de mesure

Les points de mesure, une dizaine, sont répartis sur le territoire selon des contraintes diverses (altitude, éloignement de forêts ou de bâtiments, répartition, accessibilité, etc.), afin que les scientifiques puissent disposer de données fiables et durables sur la présence de neige et que les citoyens-participants soient en capacité d’y effectuer des relevés réguliers, de préférence une à deux fois par semaine en période de neige.

<figure>
	<img src="/assets/medias-site/planter_poteau_credit_Le_Tocquet.webp" width="600">
	<figcaption>Installation d'une borne de mesure - crédit : Geoffrey Le Tocquet</figcaption>
</figure>

Les bornes de mesure, des piliers marqués d’une mire et surmontés de capteurs de température, sont plantés en altitude dans les Vosges afin d'assurer une présence plus durable de la neige. Elles marqueront l’emplacement des relevés du manteau neigeux. En fonction du versant de la montagne, des conditions climatiques, de la composition des sols, etc. le manteau neigeux n'adopte pas la même dynamique et cette étude permettra de suivre son évolution sur des multiples points dans un contexte de moyenne montagne.

### Des relevés effectués par des volontaires

Co-construit avec Niv’Ose Vosges et l’OHGE, le protocole de suivi du manteau neigeux s’inspire de méthodologies mises en place par Météo France pour assurer une récolte de données précises.
Le volontaires seront ainsi formés à effectuer des suivis nivologiques regroupant notamment des information de densité, de hauteur de neige, de qualité des cristaux… Autant d’informations utiles à la compréhension des relations entre la neige et l’environnement de basse-montagne.

<figure>
	<img src="/assets/medias-site/protocole_mesures_neige_credit_nivose.webp" width="600">
	<figcaption>Mesure de la hauteur de neige - crédit : Niv'OSE Vosges</figcaption>
</figure>


## Qu'est-ce que la recherche participative ?

La recherche participative est une façon de faire de la recherche qui implique activement les citoyens et les communautés dans le processus de recherche. Contrairement aux recherches traditionnelles, où les scientifiques travaillent souvent d'une manière plus isolée, la recherche participative invite les non-spécialistes à collaborer à différentes étapes, comme la définition des questions de recherche, la collecte de données, l'analyse des résultats ou encore la diffusion des conclusions.

Par exemple, dans ce projet de recherche participative sur le manteau neigeux, les citoyens sont formés pour mesurer de multiples caractéristiques de la neige, puis partager leurs observations avec les chercheurs via le formulaire de soumission de ce site web. Cette approche permet de combiner l'expertise des chercheurs avec l'expérience et les connaissances locales des participants. Elle peut aussi renforcer le lien entre la science et la société, en rendant la recherche plus pertinente pour les préoccupations des citoyens et plus accessible au grand public.

> Si le sujet vous intéresse, vous pouvez par exemple trouver de nombreux exemples de projets de recherche participative sur [le site web du Museum National d'Histoire Naturelle](https://www.mnhn.fr/fr/participer-a-la-science), et même participer à certains d'entre eux.

## Les structures derrière le projet

### L’Observatoire Hydro-Géochimique de l’Environnement (OHGE) de l’Université de Strasbourg

L’OHGE étudie le bassin versant du Strengbach (80ha) depuis 1986, ce qui en fait un des observatoires de la Zone Critique les plus anciens suivis dans le monde. 
L’OHGE a un rôle d’étude et de surveillance à long terme des écosystèmes et de leurs modifications en lien avec des perturbations naturelles ou anthropiques. Il s’inscrit dans les grands enjeux environnementaux de préservation des eaux, des sols et des systèmes forestiers.

<figure>
	<img src="/assets/medias-site/installation_ohge_neige_2_credit_pierret.webp" width="600">
	<figcaption>Installations météorologiques de l'OHGE - crédit : Marie-Claire Pierret</figcaption>
</figure>


### Le Jardin des sciences de l'Université de Strasbourg

Le Jardin des sciences, regroupe les actions de diffusion de la culture scientifique et technique de l’Université de Strasbourg.
Une équipe pluridisciplinaire offre un programme complet d’activités destinées à tous les publics, sur le Campus, en Ville et dans tout le territoire alsacien.

### Niv’OSE Vosges

L’association NIV’O.S.E : Niv Observations et Suivi de l’Enneigement est un « espace d’échanges et de partage entre personnes ayant un intérêt commun pour la montagne vosgienne et tous les phénomènes météorologiques et climatiques liés au massif vosgien ».

## Financement du projet

Ce projet est soutenu jusqu'en 2026 par le Commissariat au Massif des Vosges, une administration interrégionale placée auprès du préfet coordonnateur de massif et de l'ANCT, le commissariat de massif qui déploie la politique d'aménagement, de développement et de protection du massif.
Retrouvez davantage d'informations sur le missions du Commissariat au Massif des Vosges [sur leur site web](https://agence-cohesion-territoires.gouv.fr/commissariat-du-massif-des-vosges-1252)

## Et pour en savoir plus...

> Vous pouvez suivre les actualités du projet et ses différents événements via [le blog](/blog) et accéder librement aux données des relevés du manteau neigeux sur [la page des points de mesure](/bornes).

> Vous pouvez également [prendre contact](/contact) avec nous si vous avez des questions ou des demandes de collaboration.


endofsection


